@@ -3,7 +3,7 @@
   FILE: process.c
   CREATOR: eric 11 February 2000
   
-  $Id: process.c 422 2004-02-24 21:01:08Z jpr $
+  $Id: process.c 620 2007-08-28 15:09:06Z rburton $
   $Locker$
     
  (C) COPYRIGHT 2000 Eric Busboom
@@ -21,6 +21,10 @@
  
  ======================================================================*/
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <stdio.h> /* for printf */
 #include <errno.h>
 #include <string.h> /* For strerror */
