@@ -1,15 +1,15 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /* camel-store.c : Abstract class for an email store */
 
-/* 
+/*
  * Authors:
  *  Bertrand Guiheneuf <bertrand@helixcode.com>
  *  Dan Winship <danw@ximian.com>
  *
  * Copyright 1999-2003 Ximian, Inc. (www.ximian.com)
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of version 2 of the GNU Lesser General Public 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -89,9 +89,9 @@ camel_store_class_init (CamelStoreClass *camel_store_class)
 {
 	CamelObjectClass *camel_object_class = CAMEL_OBJECT_CLASS (camel_store_class);
 	CamelServiceClass *camel_service_class = CAMEL_SERVICE_CLASS(camel_store_class);
-	
+
 	parent_class = CAMEL_SERVICE_CLASS (camel_type_get_global_classfuncs (camel_service_get_type ()));
-	
+
 	/* virtual method definition */
 	camel_store_class->hash_folder_name = g_str_hash;
 	camel_store_class->compare_folder_name = g_str_equal;
@@ -109,13 +109,13 @@ camel_store_class_init (CamelStoreClass *camel_store_class)
 	camel_store_class->subscribe_folder = subscribe_folder;
 	camel_store_class->unsubscribe_folder = unsubscribe_folder;
 	camel_store_class->noop = noop;
-	
+
 	/* virtual method overload */
 	camel_service_class->construct = construct;
-	
+
 	camel_object_class->setv = store_setv;
 	camel_object_class->getv = store_getv;
-	
+
 	camel_object_class_add_event(camel_object_class, "folder_opened", NULL);
 	camel_object_class_add_event(camel_object_class, "folder_created", NULL);
 	camel_object_class_add_event(camel_object_class, "folder_deleted", NULL);
@@ -136,7 +136,7 @@ camel_store_init (void *o)
 						      (CamelCopyFunc)g_strdup, g_free);
 	} else
 		store->folders = NULL;
-	
+
 	/* set vtrash and vjunk on by default */
 	store->flags = CAMEL_STORE_VTRASH | CAMEL_STORE_VJUNK;
 	store->mode = CAMEL_STORE_READ|CAMEL_STORE_WRITE;
@@ -152,9 +152,9 @@ camel_store_finalize (CamelObject *object)
 
 	if (store->folders)
 		camel_object_bag_destroy(store->folders);
-	
+
 	g_static_rec_mutex_free (&store->priv->folder_lock);
-	
+
 	g_free (store->priv);
 }
 
@@ -211,14 +211,14 @@ get_folder (CamelStore *store, const char *folder_name, guint32 flags, CamelExce
 {
 	w(g_warning ("CamelStore::get_folder not implemented for `%s'",
 		     camel_type_to_name (CAMEL_OBJECT_GET_TYPE (store))));
-	
+
 	camel_exception_setv (ex, CAMEL_EXCEPTION_STORE_INVALID,
 			      _("Cannot get folder: Invalid operation on this store"));
-	
+
 	return NULL;
 }
 
-/** 
+/**
  * camel_store_get_folder:
  * @store: a #CamelStore object
  * @folder_name: name of the folder to get
@@ -226,20 +226,21 @@ get_folder (CamelStore *store, const char *folder_name, guint32 flags, CamelExce
  * @ex: a #CamelException
  *
  * Get a specific folder object from the store by name.
- * 
+ *
  * Returns the folder corresponding to the path @folder_name.
  **/
 CamelFolder *
 camel_store_get_folder (CamelStore *store, const char *folder_name, guint32 flags, CamelException *ex)
 {
 	CamelFolder *folder = NULL;
-	
+
+	g_return_val_if_fail (CAMEL_IS_STORE (store), NULL);
 	g_return_val_if_fail (folder_name != NULL, NULL);
-	
+
 	/* O_EXCL doesn't make sense if we aren't requesting to also create the folder if it doesn't exist */
 	if (!(flags & CAMEL_STORE_FOLDER_CREATE))
 		flags &= ~CAMEL_STORE_FOLDER_EXCL;
-	
+
 	if (store->folders) {
 		/* Try cache first. */
 		folder = camel_object_bag_reserve(store->folders, folder_name);
@@ -247,12 +248,12 @@ camel_store_get_folder (CamelStore *store, const char *folder_name, guint32 flag
 			camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM,
 					      _("Cannot create folder `%s': folder exists"),
 					      folder_name);
-			
+
 			camel_object_unref (folder);
 			return NULL;
 		}
 	}
-	
+
 	if (!folder) {
 		if ((store->flags & CAMEL_STORE_VTRASH) && strcmp(folder_name, CAMEL_VTRASH_NAME) == 0) {
 			folder = CS_CLASS(store)->get_trash(store, ex);
@@ -262,7 +263,7 @@ camel_store_get_folder (CamelStore *store, const char *folder_name, guint32 flag
 			folder = CS_CLASS (store)->get_folder(store, folder_name, flags, ex);
 			if (folder) {
 				CamelVeeFolder *vfolder;
-				
+
 				if ((store->flags & CAMEL_STORE_VTRASH)
 				    && (vfolder = camel_object_bag_get(store->folders, CAMEL_VTRASH_NAME))) {
 					camel_vee_folder_add_folder(vfolder, folder);
@@ -291,7 +292,7 @@ camel_store_get_folder (CamelStore *store, const char *folder_name, guint32 flag
 	if (camel_debug_start(":store")) {
 		char *u = camel_url_to_string(((CamelService *)store)->url, CAMEL_URL_HIDE_PASSWORD);
 
-		printf("CamelStore('%s'):get_folder('%s', %u) = %p\n", u, folder_name, flags, folder);
+		printf("CamelStore('%s'):get_folder('%s', %u) = %p\n", u, folder_name, flags, (void *) folder);
 		if (ex && ex->id)
 			printf("  failed: '%s'\n", ex->desc);
 		g_free(u);
@@ -307,20 +308,20 @@ create_folder (CamelStore *store, const char *parent_name,
 {
 	w(g_warning ("CamelStore::create_folder not implemented for `%s'",
 		     camel_type_to_name (CAMEL_OBJECT_GET_TYPE (store))));
-	
+
 	camel_exception_setv (ex, CAMEL_EXCEPTION_STORE_INVALID,
 			      _("Cannot create folder: Invalid operation on this store"));
-	
+
 	return NULL;
 }
 
-/** 
+/**
  * camel_store_create_folder:
  * @store: a #CamelStore object
  * @parent_name: name of the new folder's parent, or %NULL
  * @folder_name: name of the folder to create
  * @ex: a #CamelException
- * 
+ *
  * Creates a new folder as a child of an existing folder.
  * @parent_name can be %NULL to create a new top-level folder.
  *
@@ -357,7 +358,7 @@ cs_delete_cached_folder(CamelStore *store, const char *folder_name)
 	if (store->folders
 	    && (folder = camel_object_bag_get(store->folders, folder_name))) {
 		CamelVeeFolder *vfolder;
-			
+
 		if ((store->flags & CAMEL_STORE_VTRASH)
 		    && (vfolder = camel_object_bag_get(store->folders, CAMEL_VTRASH_NAME))) {
 			camel_vee_folder_remove_folder(vfolder, folder);
@@ -384,12 +385,12 @@ delete_folder (CamelStore *store, const char *folder_name, CamelException *ex)
 		     camel_type_to_name (CAMEL_OBJECT_GET_TYPE (store))));
 }
 
-/** 
+/**
  * camel_store_delete_folder:
  * @store: a #CamelStore object
  * @folder_name: name of the folder to delete
  * @ex: a #CamelException
- * 
+ *
  * Deletes the named folder. The folder must be empty.
  **/
 void
@@ -415,7 +416,7 @@ camel_store_delete_folder (CamelStore *store, const char *folder_name, CamelExce
 		cs_delete_cached_folder(store, folder_name);
 	else
 		camel_exception_xfer(ex, &local);
-	
+
 	CAMEL_STORE_UNLOCK(store, folder_lock);
 }
 
@@ -432,7 +433,7 @@ rename_folder (CamelStore *store, const char *old_name, const char *new_name, Ca
  * @old_namein: the current name of the folder
  * @new_name: the new name of the folder
  * @ex: a #CamelException
- * 
+ *
  * Rename a named folder to a new name.
  **/
 void
@@ -508,7 +509,7 @@ camel_store_rename_folder (CamelStore *store, const char *old_namein, const char
 		/* Emit renamed signal */
 		if (store->flags & CAMEL_STORE_SUBSCRIPTIONS)
 			flags |= CAMEL_STORE_FOLDER_INFO_SUBSCRIBED;
-		
+
 		reninfo.old_base = (char *)old_name;
 		reninfo.new = ((CamelStoreClass *)((CamelObject *)store)->klass)->get_folder_info(store, new_name, flags, ex);
 		if (reninfo.new != NULL) {
@@ -540,7 +541,7 @@ get_inbox (CamelStore *store, CamelException *ex)
 	return CS_CLASS (store)->get_folder (store, "inbox", 0, ex);
 }
 
-/** 
+/**
  * camel_store_get_inbox:
  * @store: a #CamelStore object
  * @ex: a #CamelException
@@ -591,7 +592,7 @@ get_junk(CamelStore *store, CamelException *ex)
 	return get_special(store, CAMEL_VTRASH_FOLDER_JUNK);
 }
 
-/** 
+/**
  * camel_store_get_trash:
  * @store: a #CamelStore object
  * @ex: a #CamelException
@@ -608,7 +609,7 @@ camel_store_get_trash (CamelStore *store, CamelException *ex)
 		return camel_store_get_folder(store, CAMEL_VTRASH_NAME, 0, ex);
 }
 
-/** 
+/**
  * camel_store_get_junk:
  * @store: a #CamelStore object
  * @ex: a #CamelException
@@ -672,7 +673,7 @@ get_folder_info (CamelStore *store, const char *top, guint32 flags, CamelExcepti
 {
 	w(g_warning ("CamelStore::get_folder_info not implemented for `%s'",
 		     camel_type_to_name (CAMEL_OBJECT_GET_TYPE (store))));
-	
+
 	return NULL;
 }
 
@@ -682,16 +683,16 @@ add_special_info (CamelStore *store, CamelFolderInfo *info, const char *name, co
 	CamelFolderInfo *fi, *vinfo, *parent;
 	char *uri, *path;
 	CamelURL *url;
-	
+
 	g_return_if_fail (info != NULL);
-	
+
 	parent = NULL;
 	for (fi = info; fi; fi = fi->next) {
 		if (!strcmp (fi->full_name, name))
 			break;
 		parent = fi;
 	}
-	
+
 	/* create our vTrash/vJunk URL */
 	url = camel_url_new (info->uri, NULL);
 	if (((CamelService *) store)->provider->url_flags & CAMEL_URL_FRAGMENT_IS_PATH) {
@@ -701,10 +702,10 @@ add_special_info (CamelStore *store, CamelFolderInfo *info, const char *name, co
 		camel_url_set_path (url, path);
 		g_free (path);
 	}
-	
+
 	uri = camel_url_to_string (url, CAMEL_URL_HIDE_ALL);
 	camel_url_free (url);
-	
+
 	if (fi) {
 		/* We're going to replace the physical Trash/Junk folder with our vTrash/vJunk folder */
 		vinfo = fi;
@@ -713,17 +714,17 @@ add_special_info (CamelStore *store, CamelFolderInfo *info, const char *name, co
 		g_free (vinfo->uri);
 	} else {
 		/* There wasn't a Trash/Junk folder so create a new folder entry */
-		vinfo = g_new0 (CamelFolderInfo, 1);
-		
+		vinfo = camel_folder_info_new ();
+
 		g_assert(parent != NULL);
-		
+
 		vinfo->flags |= CAMEL_FOLDER_NOINFERIORS | CAMEL_FOLDER_SUBSCRIBED;
-		
+
 		/* link it into the right spot */
 		vinfo->next = parent->next;
 		parent->next = vinfo;
 	}
-	
+
 	/* Fill in the new fields */
 	vinfo->flags |= flags;
 	vinfo->full_name = g_strdup (name);
@@ -771,7 +772,7 @@ dump_fi(CamelFolderInfo *fi, int depth)
  * determine that information quickly.  If @flags includes
  * #CAMEL_STORE_FOLDER_INFO_NO_VIRTUAL, don't include special virtual
  * folders (such as vTrash or vJunk).
- * 
+ *
  * The CAMEL_STORE_FOLDER_INFO_FAST flag should be considered
  * deprecated; most backends will behave the same whether it is
  * supplied or not.  The only guaranteed way to get updated folder
@@ -784,11 +785,11 @@ CamelFolderInfo *
 camel_store_get_folder_info(CamelStore *store, const char *top, guint32 flags, CamelException *ex)
 {
 	CamelFolderInfo *info;
-	
+
 	g_return_val_if_fail (CAMEL_IS_STORE (store), NULL);
 
 	info = CS_CLASS (store)->get_folder_info (store, top, flags, ex);
-	
+
 	if (info && (top == NULL || *top == '\0') && (flags & CAMEL_STORE_FOLDER_INFO_NO_VIRTUAL) == 0) {
 		if (info->uri && (store->flags & CAMEL_STORE_VTRASH))
 			/* the name of the Trash folder, used for deleted messages */
@@ -800,12 +801,12 @@ camel_store_get_folder_info(CamelStore *store, const char *top, guint32 flags, C
 
 	if (camel_debug_start("store:folder_info")) {
 		char *url = camel_url_to_string(((CamelService *)store)->url, CAMEL_URL_HIDE_ALL);
-		printf("Get folder info(%p:%s, '%s') =\n", store, url, top?top:"<null>");
+		printf("Get folder info(%p:%s, '%s') =\n", (void *) store, url, top?top:"<null>");
 		g_free(url);
 		dump_fi(info, 2);
 		camel_debug_end();
 	}
-	
+
 	return info;
 }
 
@@ -873,16 +874,27 @@ camel_folder_info_free (CamelFolderInfo *fi)
 		g_free (fi->name);
 		g_free (fi->full_name);
 		g_free (fi->uri);
-		g_free (fi);
+		g_slice_free (CamelFolderInfo, fi);
 	}
 }
 
+/**
+ * camel_folder_info_new:
+ *
+ * Return value: a new empty CamelFolderInfo instance
+ **/
+CamelFolderInfo *
+camel_folder_info_new (void)
+{
+	return g_slice_new0 (CamelFolderInfo);
+}
+
 static int
 folder_info_cmp (const void *ap, const void *bp)
 {
 	const CamelFolderInfo *a = ((CamelFolderInfo **)ap)[0];
 	const CamelFolderInfo *b = ((CamelFolderInfo **)bp)[0];
-	
+
 	return strcmp (a->full_name, b->full_name);
 }
 
@@ -921,14 +933,14 @@ camel_folder_info_build (GPtrArray *folders, const char *namespace,
 	nlen = strlen (namespace);
 
 	qsort (folders->pdata, folders->len, sizeof (folders->pdata[0]), folder_info_cmp);
-	
+
 	/* Hash the folders. */
 	hash = g_hash_table_new (g_str_hash, g_str_equal);
 	for (i = 0; i < folders->len; i++) {
 		fi = folders->pdata[i];
 		g_hash_table_insert (hash, fi->full_name, fi);
 	}
-	
+
 	/* Now find parents. */
 	for (i = 0; i < folders->len; i++) {
 		fi = folders->pdata[i];
@@ -945,7 +957,7 @@ camel_folder_info_build (GPtrArray *folders, const char *namespace,
 				CamelURL *url;
 				char *sep;
 
-				pfi = g_new0 (CamelFolderInfo, 1);
+				pfi = camel_folder_info_new ();
 				if (short_names) {
 					pfi->name = strrchr (pname, separator);
 					if (pfi->name)
@@ -954,21 +966,21 @@ camel_folder_info_build (GPtrArray *folders, const char *namespace,
 						pfi->name = g_strdup (pname);
 				} else
 					pfi->name = g_strdup (pname);
-				
+
 				url = camel_url_new (fi->uri, NULL);
 				if (url->fragment)
 					path = url->fragment;
 				else
 					path = url->path + 1;
-				
+
 				sep = strrchr (path, separator);
 				if (sep)
 					*sep = '\0';
 				else
 					d(g_warning ("huh, no \"%c\" in \"%s\"?", separator, fi->uri));
-				
+
 				pfi->full_name = g_strdup (path);
-				
+
 				/* since this is a "fake" folder node, it is not selectable */
 				camel_url_set_param (url, "noselect", "yes");
 				pfi->uri = camel_url_to_string (url, 0);
@@ -1005,7 +1017,7 @@ camel_folder_info_build (GPtrArray *folders, const char *namespace,
 			tail = fi;
 		}
 	}
-	
+
 	return top;
 }
 
@@ -1014,14 +1026,14 @@ folder_info_clone_rec(CamelFolderInfo *fi, CamelFolderInfo *parent)
 {
 	CamelFolderInfo *info;
 
-	info = g_malloc(sizeof(*info));
+	info = camel_folder_info_new ();
 	info->parent = parent;
 	info->uri = g_strdup(fi->uri);
 	info->name = g_strdup(fi->name);
 	info->full_name = g_strdup(fi->full_name);
 	info->unread = fi->unread;
 	info->flags = fi->flags;
-	
+
 	if (fi->next)
 		info->next = folder_info_clone_rec(fi->next, parent);
 	else
@@ -1073,7 +1085,7 @@ folder_subscribed(CamelStore *store, const char *folder_name)
 {
 	w(g_warning ("CamelStore::folder_subscribed not implemented for `%s'",
 		     camel_type_to_name (CAMEL_OBJECT_GET_TYPE (store))));
-	
+
 	return FALSE;
 }
 
@@ -1206,23 +1218,23 @@ camel_store_folder_uri_equal (CamelStore *store, const char *uri0, const char *u
 	CamelProvider *provider;
 	CamelURL *url0, *url1;
 	int equal;
-	
+
 	g_return_val_if_fail (CAMEL_IS_STORE (store), FALSE);
 	g_return_val_if_fail (uri0 && uri1, FALSE);
-	
+
 	provider = ((CamelService *) store)->provider;
-	
+
 	if (!(url0 = camel_url_new (uri0, NULL)))
 		return FALSE;
-	
+
 	if (!(url1 = camel_url_new (uri1, NULL))) {
 		camel_url_free (url0);
 		return FALSE;
 	}
-	
+
 	if ((equal = provider->url_equal (url0, url1))) {
 		const char *name0, *name1;
-		
+
 		if (provider->url_flags & CAMEL_URL_FRAGMENT_IS_PATH) {
 			name0 = url0->fragment;
 			name1 = url1->fragment;
@@ -1236,13 +1248,13 @@ camel_store_folder_uri_equal (CamelStore *store, const char *uri0, const char *u
 
 		if (name1 == NULL)
 			g_warning("URI is badly formed, missing folder name: %s", uri1);
-		
+
 		equal = name0 && name1 && CS_CLASS (store)->compare_folder_name (name0, name1);
 	}
-	
+
 	camel_url_free (url0);
 	camel_url_free (url1);
-	
+
 	return equal;
 }
 
