@@ -52,6 +52,9 @@ static char *convert(const char *in, const char *from, const char *to)
 		char *nout, *noutp;
 		iconv_t ic = iconv_open(from, to);
 
+		if (ic == (iconv_t)-1)
+			goto fail;
+
 		inp = out;
 		inlen = strlen(out);
 		outlen = inlen*5 + 16;
@@ -68,6 +71,7 @@ static char *convert(const char *in, const char *from, const char *to)
 		printf("Camel thinks the best encoding of '%s' is %s, although we converted from %s\n",
 		       in, camel_charset_best(out, strlen(out)), from);
 	}
+fail:
 #endif
 
 	return out;
@@ -301,7 +305,7 @@ int main(int argc, char **argv)
 		check(strcmp(format, test_address[i].utf8) == 0);
 		test_free(format);
 		pull();
-		
+
 		push("Comparing re-encoded output");
 		addr2 = CAMEL_INTERNET_ADDRESS(camel_internet_address_new());
 		enc = camel_address_encode(CAMEL_ADDRESS(addr));
